@@ -1,6 +1,6 @@
 package Business::PayPal::SDK;
 
-#$Id: $
+#$Id: SDK.pm,v 1.2 2005/11/16 02:25:42 jacob Exp $
 
 use strict;
 use warnings;
@@ -66,7 +66,7 @@ sub init_java {
     DIRECTORY => "/tmp",
   );
   Inline::Java::study_classes(\@study);
-  package C::PayPal;
+  package Business::PayPal::SDK;
 
   foreach my $ac (@ACCESSORS) {
     if (!$s->$ac and !$PPCONINFO) {
@@ -98,7 +98,11 @@ sub init_java {
   };
 
   if ($@) {
-    $s->error("setAPIProfile failed: [" . $@->getMessage() . '] [' . $@->toString() . ']');
+    if (ref $@) {
+      $s->error("setAPIProfile failed: [" . $@->getMessage() . '] [' . $@ . ']');
+    } else {
+      $s->error("setAPIProfile failed: [$@]");
+    }
     return undef;
   }
 
@@ -153,7 +157,7 @@ sub DoDirectPayment {
       )
     ]
   );
-  package C::PayPal;
+  package Business::PayPal::SDK;
 
   my $resp;
   eval {
@@ -240,7 +244,7 @@ sub _getCreditCard {
       )
     ]
   );
-  package C::PayPal;
+  package Business::PayPal::SDK;
 
   my $creditCard;
   eval {
@@ -280,7 +284,7 @@ sub _getPersonName {
       )
     ]
   );
-  package C::PayPal;
+  package Business::PayPal::SDK;
 
   my $payerName;
   eval {
@@ -318,7 +322,7 @@ sub _getCardType {
       )
     ]
   );
-  package C::PayPal;
+  package Business::PayPal::SDK;
 
   my $ccType;
   eval {
@@ -375,7 +379,7 @@ sub DoExpressCheckoutPayment {
       )
     ]
   );
-  package C::PayPal;
+  package Business::PayPal::SDK;
 
   my $request = com::paypal::soap::api::DoExpressCheckoutPaymentRequestType->new();
   my $requestDetails = com::paypal::soap::api::DoExpressCheckoutPaymentRequestDetailsType->new();
@@ -501,7 +505,7 @@ sub GetExpressCheckoutDetails {
       )
     ]
   );
-  package C::PayPal;
+  package Business::PayPal::SDK;
 
   my $request = com::paypal::soap::api::GetExpressCheckoutDetailsRequestType->new();
   $request->setToken($args->{token});
@@ -592,30 +596,41 @@ sub SetExpressCheckout {
       )
     ]
   );
-  package C::PayPal;
+  package Business::PayPal::SDK;
 
-  my $OrderTotalObj = com::paypal::soap::api::BasicAmountType->new($args->{OrderTotal});
-  $OrderTotalObj->setCurrencyID($com::paypal::soap::api::CurrencyCodeType::USD);
-  my $MaxAmountObj;
-  if ($args->{MaxAmount}) {
-    $MaxAmountObj = com::paypal::soap::api::BasicAmountType->new($args->{MaxAmount});
-    $MaxAmountObj->setCurrencyID($com::paypal::soap::api::CurrencyCodeType::USD);
-  }
+  my $resp;
+  eval {
+    my $OrderTotalObj = com::paypal::soap::api::BasicAmountType->new($args->{OrderTotal});
+    $OrderTotalObj->setCurrencyID($com::paypal::soap::api::CurrencyCodeType::USD);
+    my $MaxAmountObj;
+    if ($args->{MaxAmount}) {
+      $MaxAmountObj = com::paypal::soap::api::BasicAmountType->new($args->{MaxAmount});
+      $MaxAmountObj->setCurrencyID($com::paypal::soap::api::CurrencyCodeType::USD);
+    }
   
-  my $ReqDetails = com::paypal::soap::api::SetExpressCheckoutRequestDetailsType->new();
-  $ReqDetails->setReturnURL($args->{ReturnURL});
-  $ReqDetails->setCancelURL($args->{CancelURL});
-  $ReqDetails->setOrderTotal($OrderTotalObj);
+    my $ReqDetails = com::paypal::soap::api::SetExpressCheckoutRequestDetailsType->new();
+    $ReqDetails->setReturnURL($args->{ReturnURL});
+    $ReqDetails->setCancelURL($args->{CancelURL});
+    $ReqDetails->setOrderTotal($OrderTotalObj);
   
-  $ReqDetails->setCustom($args->{Custom}) if $args->{Custom};
-  $ReqDetails->setInvoiceID($args->{InvoiceID}) if $args->{InvoiceID};
+    $ReqDetails->setCustom($args->{Custom}) if $args->{Custom};
+    $ReqDetails->setInvoiceID($args->{InvoiceID}) if $args->{InvoiceID};
 
-  my $request = com::paypal::soap::api::SetExpressCheckoutRequestType->new();
-  $request->setSetExpressCheckoutRequestDetails($ReqDetails);
-
-  my $resp = $s->paypal->call("SetExpressCheckout", $request);
+    my $request = com::paypal::soap::api::SetExpressCheckoutRequestType->new();
+    $request->setSetExpressCheckoutRequestDetails($ReqDetails);
+    $resp = $s->paypal->call("SetExpressCheckout", $request);
+  };
   my $ret = {};
 
+  if ($@) {
+    if (ref $@) {
+      $s->error("SetExpressCheckout failed: [" . $@->getMessage() . '] [' . $@ . ']');
+    } else {
+      $s->error("SetExpressCheckout failed: [$@]");
+    }
+    return undef;
+  }
+
   if ($resp->getToken()) {
     $ret->{token} = $resp->getToken();
     return $ret;
@@ -649,7 +664,7 @@ sub _getAddress {
       )
     ]
   );
-  package C::PayPal;
+  package Business::PayPal::SDK;
  
   my $AddressObj;
   eval { 
@@ -689,7 +704,7 @@ sub _getCountryCode {
       )
     ]
   );
-  package C::PayPal;
+  package Business::PayPal::SDK;
   
   my $code;
   eval {
@@ -742,22 +757,28 @@ sub TransactionSearch {
         com.paypal.soap.api.TransactionSearchRequestType
         com.paypal.soap.api.TransactionSearchResponseType
         com.paypal.soap.api.AckCodeType
+        com.paypal.sdk.exceptions.TransactionException
+        com.paypal.sdk.exceptions.PayPalException
+        com.paypal.soap.api.ErrorType
         java.util.Calendar
         java.lang.String
       )
     ]
   );
-  package C::PayPal;
+  package Business::PayPal::SDK;
   
   my $request = com::paypal::soap::api::TransactionSearchRequestType->new();
-  my $jcal = java::util::Calendar->getInstance();
+  my $jcal = Inline::Java::cast('java.util.Calendar', java::util::Calendar->getInstance());
   $jcal->set(@{$args->{date}});
   $request->setStartDate($jcal);
 
   my $resp = $s->paypal->call("TransactionSearch", $request);
 
   my $ackcode = $resp->getAck();
+
   print $ackcode->toString;
+  my $ret = {};
+  $ret->{ErrorCodes} = $s->_getErrorHash($resp->getErrors);
 }
 
 sub _getDateString {
@@ -792,9 +813,9 @@ sub _getErrorHash {
 
   my $ErrorCodes = {};
   foreach my $err (@$errors) {
-    $s->error($err->getLongMessage);
     my $token = $err->getErrorCode;
-    $ErrorCodes->{$token->toString} = $err->getLongMessage;
+    $s->error($err->getLongMessage) if $err;
+    $ErrorCodes->{$token->toString} = $err->getLongMessage if ($err && $token);
   }
   return $ErrorCodes;
 }
